@@ -108,39 +108,62 @@ class DjangoEnv(Env):
     def __init__(self, *args, **kwargs):
         self.prefix = kwargs.pop('prefix', _DEFAULT_ENV_PREFIX)
         exception = kwargs.pop('exception', ImproperlyConfigured)
-        super(DjangoEnv, self).__init__(*args, exception=exception, **kwargs)
+        super().__init__(*args, exception=exception, **kwargs)
 
-    def get(self, var, default=None, prefix=_DEFAULT_PREFIX):
+    def _with_prefix(self, var, prefix):
         if prefix is _DEFAULT_PREFIX:
             prefix = self.prefix
         if var and prefix and not var.startswith(prefix) and not self.is_set(var):
             var = f"{prefix}{var}"
-        return super().get(var, default)
+        return var
 
-    def check_var(self, var, default=None, raise_error=True):
+    def get(self, var, default=None, prefix=_DEFAULT_PREFIX):
+        return super().get(self._with_prefix(var, prefix=prefix), default)
+
+    def int(self, var, default=None, prefix=_DEFAULT_PREFIX) -> int:
+        val = self.get(var, default, prefix=prefix)
+        return self._int(val)
+
+    def float(self, var, default=None, prefix=_DEFAULT_PREFIX) -> float:
+        val = self.get(var, default, prefix=prefix)
+        return self._float(val)
+
+    def bool(self, var, default=None, prefix=_DEFAULT_PREFIX) -> bool:
+        val = self.get(var, default, prefix=prefix)
+        return val if isinstance(val, (bool, int)) else self.is_true(val)
+
+    def list(self, var, default=None, prefix=_DEFAULT_PREFIX) -> list:
+        val = self.get(var, default, prefix=prefix)
+        return val if isinstance(val, (list, tuple)) else self._list(val)
+
+    def check_var(self, var, default=None, prefix=_DEFAULT_PREFIX, raise_error=True):
         """
         override to insert prefix unless the raw var is set
         """
-        if var and self.prefix and not var.startswith(self.prefix) and not self.is_set(var):
-            var = f"{self.prefix}{var}"
-        return super(DjangoEnv, self).check_var(var, default=default, raise_error=raise_error)
+        var = self._with_prefix(var, prefix=prefix)
+        return super().check_var(var, default=default, raise_error=raise_error)
 
-    def __call__(self, var=None, default=None, prefix=_DEFAULT_PREFIX, optional=False, raise_error=False):
+    def __call__(self, var=None, default=None, prefix=_DEFAULT_PREFIX, type=str, optional=False, raise_error=False):
         # This is tied to django-class-settings (optional dependency), which allows
         # omitting the 'name' parameter and using the setting name instead'
         if var is None:
+            kwargs = {"name": var, "prefix": prefix if prefix is None else self.prefix, "default": default}
+            # try using class_settings version if installed
             try:
                 # noinspection PyUnresolvedReferences
                 from class_settings.env import DeferredEnv
-
-                kwargs = {"name": var, "prefix": prefix if prefix is None else self.prefix, "default": default}
                 return DeferredEnv(self, kwargs=kwargs, optional=optional)
             except ImportError:
-                # class settings not installed
                 pass
-        if raise_error and not self.is_set(var):
-            self.exception(f"Expected '{var}' is not set in environment")
-        return self.get(var, prefix=None, default=default)
+            # otherwise use our own implementation (handles module level vars)
+            from .deferred import DeferredSetting
+            # class settings not installed
+            return DeferredSetting(env=self, kwargs=kwargs)
+        try:
+            return self._typemap[type](var, default=default, prefix=prefix)
+        except KeyError:
+            pass
+        return self.get(var, default=default, prefix=prefix)
 
     # Django-specific additions
 
